==> ejc-sale-impl-3.0.0-20220404.055637-20-sources.jar: com/ejianc/business/sale/bean/ManualshipmentEntity.java <==
package com.ejianc.business.sale.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 发货管理
 * 
 * @author generator
 * 
 */
 @TableName("ejc_sale_manualshipment")
public class ManualshipmentEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="customer_id")
    private Long customerId; // 客户主键
    @TableField(value="customer_name")
    private String customerName; // 客户名称
    @TableField(value="project_id")
    private Long projectId; // 工程主键
    @TableField(value="project_name")
    private String projectName; // 工程名称
    @TableField(value="worksite_id")
    private Long worksiteId; // 工地主键
    @TableField(value="worksite_name")
    private String worksiteName; // 工地名称
    @TableField(value="unit_id")
    private Long unitId; // 机组主键
    @TableField(value="unit_name")
    private String unitName; // 机组名称
    @TableField(value="product_id")
    private Long productId; // 产品主键
    @TableField(value="product_name")
    private String productName; // 产品名称
    @TableField(value="ship_date")
    private Date shipDate; // 发货日期
    @TableField(value="temperature")
    private Long temperature; // 温度
    @TableField(value="car_id")
    private Long carId; // 车辆主键
    @TableField(value="number_plate")
    private String numberPlate; // 车号
    @TableField(value="tare")
    private Long tare; // 皮重
    @TableField(value="receipts")
    private String receipts; // 收款情况
    @TableField(value="gross_weight")
    private Long grossWeight; // 毛重
    @TableField(value="net_weight")
    private Long netWeight; // 净重
    @TableField(value="shipping_method")
    private Integer shippingMethod; // 运输方式:0代运1自运
    @TableField(value="shippers_id")
    private Long shippersId; // 运输单位主键
    @TableField(value="shippers_name")
    private String shippersName; // 运输单位名称
    @TableField(value="distance")
    private Long distance; // 运输距离
    @TableField(value="freight")
    private BigDecimal freight; // 运费
    @TableField(value="remake")
    private String remake; // 备注
    @TableField(value="bill_state")
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="org_id")
    private Long orgId; // 所属组织id
    @TableField(value="org_name")
    private String orgName; // 所属组织名称
    @TableField(value="bill_code")
    private String billCode; // 单据编号
    
    
    

    public Long getCustomerId() {
        return customerId;
    }

    public void setCustomerId(Long customerId) {
        this.customerId = customerId;
    }
    public String getCustomerName() {
        return customerName;
    }

    public void setCustomerName(String customerName) {
        this.customerName = customerName;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getWorksiteId() {
        return worksiteId;
    }

    public void setWorksiteId(Long worksiteId) {
        this.worksiteId = worksiteId;
    }
    public String getWorksiteName() {
        return worksiteName;
    }

    public void setWorksiteName(String worksiteName) {
        this.worksiteName = worksiteName;
    }
    public Long getUnitId() {
        return unitId;
    }

    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public Long getProductId() {
        return productId;
    }

    public void setProductId(Long productId) {
        this.productId = productId;
    }
    public String getProductName() {
        return productName;
    }

    public void setProductName(String productName) {
        this.productName = productName;
    }
    public Date getShipDate() {
        return shipDate;
    }

    public void setShipDate(Date shipDate) {
        this.shipDate = shipDate;
    }
    public Long getTemperature() {
        return temperature;
    }

    public void setTemperature(Long temperature) {
        this.temperature = temperature;
    }
    public Long getCarId() {
        return carId;
    }

    public void setCarId(Long carId) {
        this.carId = carId;
    }
    public String getNumberPlate() {
        return numberPlate;
    }

    public void setNumberPlate(String numberPlate) {
        this.numberPlate = numberPlate;
    }
    public Long getTare() {
        return tare;
    }

    public void setTare(Long tare) {
        this.tare = tare;
    }
    public String getReceipts() {
        return receipts;
    }

    public void setReceipts(String receipts) {
        this.receipts = receipts;
    }
    public Long getGrossWeight() {
        return grossWeight;
    }

    public void setGrossWeight(Long grossWeight) {
        this.grossWeight = grossWeight;
    }
    public Long getNetWeight() {
        return netWeight;
    }

    public void setNetWeight(Long netWeight) {
        this.netWeight = netWeight;
    }
    public Integer getShippingMethod() {
        return shippingMethod;
    }

    public void setShippingMethod(Integer shippingMethod) {
        this.shippingMethod = shippingMethod;
    }
    public Long getShippersId() {
        return shippersId;
    }

    public void setShippersId(Long shippersId) {
        this.shippersId = shippersId;
    }
    public String getShippersName() {
        return shippersName;
    }

    public void setShippersName(String shippersName) {
        this.shippersName = shippersName;
    }
    public Long getDistance() {
        return distance;
    }

    public void setDistance(Long distance) {
        this.distance = distance;
    }
    public BigDecimal getFreight() {
        return freight;
    }

    public void setFreight(BigDecimal freight) {
        this.freight = freight;
    }
    public String getRemake() {
        return remake;
    }

    public void setRemake(String remake) {
        this.remake = remake;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    
}

==> ejc-sale-impl-3.0.0-20220502.092958-73-sources.jar: com/ejianc/business/sale/bean/ManualshipmentEntity.java <==
package com.ejianc.business.sale.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 发货管理
 * 
 * @author generator
 * 
 */
 @TableName("ejc_sale_manualshipment")
public class  ManualshipmentEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="customer_id")
    private Long customerId; // 客户主键
    @TableField(value="customer_name")
    private String customerName; // 客户名称
    @TableField(value="project_id")
    private Long projectId; // 工程主键
    @TableField(value="project_name")
    private String projectName; // 工程名称
    @TableField(value="worksite_id")
    private Long worksiteId; // 工地主键
    @TableField(value="worksite_name")
    private String worksiteName; // 工地名称
    @TableField(value="unit_id")
    private Long unitId; // 机组主键
    @TableField(value="unit_name")
    private String unitName; // 机组名称
    @TableField(value="product_id")
    private Long productId; // 产品主键
    @TableField(value="product_name")
    private String productName; // 产品名称
    @TableField(value="ship_date")
    private Date shipDate; // 发货日期
    @TableField(value="temperature")
    private Long temperature; // 温度
    @TableField(value="car_id")
    private Long carId; // 车辆主键
    @TableField(value="number_plate")
    private String numberPlate; // 车号
    @TableField(value="tare")
    private BigDecimal tare; // 皮重
    @TableField(value="receipts")
    private String receipts; // 收款情况
    @TableField(value="gross_weight")
    private BigDecimal grossWeight; // 毛重
    @TableField(value="net_weight")
    private BigDecimal netWeight; // 净重
    @TableField(value="shipping_method")
    private Integer shippingMethod; // 运输方式:0代运1自运
    @TableField(value="shippers_id")
    private Long shippersId; // 运输单位主键
    @TableField(value="shippers_name")
    private String shippersName; // 运输单位名称
    @TableField(value="distance")
    private BigDecimal distance; // 运输距离
    @TableField(value="freight")
    private BigDecimal freight; // 运费
    @TableField(value="remake")
    private String remake; // 备注
    @TableField(value="bill_state")
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="org_id")
    private Long orgId; // 所属组织id
    @TableField(value="org_name")
    private String orgName; // 所属组织名称
    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="shipment_type")
    private Integer shipmentType; // 发货类型  0-手动发货 1-自动发货
    @TableField(value="freight_status")
    private Integer freightStatus; // 运费确认标志  0-已确认 1-未确认
    @TableField(value="freight_time")
    private Date freightTime; // 运费确认时间
    @TableField(value="confirm_number")
    private BigDecimal confirmNumber; // 确认数
    @TableField(value="receipt_status")
    private Integer receiptStatus; // 回执单状态  0-已勾  1-未勾
    @TableField(value="paid_money")
    private BigDecimal paidMoney; // 已付运费
    @TableField(value="outstanding_money")
    private BigDecimal outstandingMoney; // 未付运费
    
    
    

    public Long getCustomerId() {
        return customerId;
    }

    public void setCustomerId(Long customerId) {
        this.customerId = customerId;
    }
    public String getCustomerName() {
        return customerName;
    }

    public void setCustomerName(String customerName) {
        this.customerName = customerName;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getWorksiteId() {
        return worksiteId;
    }

    public void setWorksiteId(Long worksiteId) {
        this.worksiteId = worksiteId;
    }
    public String getWorksiteName() {
        return worksiteName;
    }

    public void setWorksiteName(String worksiteName) {
        this.worksiteName = worksiteName;
    }
    public Long getUnitId() {
        return unitId;
    }

    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public Long getProductId() {
        return productId;
    }

    public void setProductId(Long productId) {
        this.productId = productId;
    }
    public String getProductName() {
        return productName;
    }

    public void setProductName(String productName) {
        this.productName = productName;
    }
    public Date getShipDate() {
        return shipDate;
    }

    public void setShipDate(Date shipDate) {
        this.shipDate = shipDate;
    }
    public Long getTemperature() {
        return temperature;
    }

    public void setTemperature(Long temperature) {
        this.temperature = temperature;
    }
    public Long getCarId() {
        return carId;
    }

    public void setCarId(Long carId) {
        this.carId = carId;
    }
    public String getNumberPlate() {
        return numberPlate;
    }

    public void setNumberPlate(String numberPlate) {
        this.numberPlate = numberPlate;
    }
    public BigDecimal getTare() {
        return tare;
    }

    public void setTare(BigDecimal tare) {
        this.tare = tare;
    }
    public String getReceipts() {
        return receipts;
    }

    public void setReceipts(String receipts) {
        this.receipts = receipts;
    }
    public BigDecimal getGrossWeight() {
        return grossWeight;
    }

    public void setGrossWeight(BigDecimal grossWeight) {
        this.grossWeight = grossWeight;
    }
    public BigDecimal getNetWeight() {
        return netWeight;
    }

    public void setNetWeight(BigDecimal netWeight) {
        this.netWeight = netWeight;
    }
    public Integer getShippingMethod() {
        return shippingMethod;
    }

    public void setShippingMethod(Integer shippingMethod) {
        this.shippingMethod = shippingMethod;
    }
    public Long getShippersId() {
        return shippersId;
    }

    public void setShippersId(Long shippersId) {
        this.shippersId = shippersId;
    }
    public String getShippersName() {
        return shippersName;
    }

    public void setShippersName(String shippersName) {
        this.shippersName = shippersName;
    }
    public BigDecimal getDistance() {
        return distance;
    }

    public void setDistance(BigDecimal distance) {
        this.distance = distance;
    }
    public BigDecimal getFreight() {
        return freight;
    }

    public void setFreight(BigDecimal freight) {
        this.freight = freight;
    }
    public String getRemake() {
        return remake;
    }

    public void setRemake(String remake) {
        this.remake = remake;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public Integer getShipmentType() {
        return shipmentType;
    }

    public void setShipmentType(Integer shipmentType) {
        this.shipmentType = shipmentType;
    }

    public Integer getFreightStatus() {
        return freightStatus;
    }

    public void setFreightStatus(Integer freightStatus) {
        this.freightStatus = freightStatus;
    }

    public Date getFreightTime() {
        return freightTime;
    }

    public void setFreightTime(Date freightTime) {
        this.freightTime = freightTime;
    }

    public BigDecimal getConfirmNumber() {
        return confirmNumber;
    }

    public void setConfirmNumber(BigDecimal confirmNumber) {
        this.confirmNumber = confirmNumber;
    }

    public Integer getReceiptStatus() {
        return receiptStatus;
    }

    public void setReceiptStatus(Integer receiptStatus) {
        this.receiptStatus = receiptStatus;
    }

    public BigDecimal getPaidMoney() {
        return paidMoney;
    }

    public void setPaidMoney(BigDecimal paidMoney) {
        this.paidMoney = paidMoney;
    }

    public BigDecimal getOutstandingMoney() {
        return outstandingMoney;
    }

    public void setOutstandingMoney(BigDecimal outstandingMoney) {
        this.outstandingMoney = outstandingMoney;
    }
}
